@@ -15,13 +15,21 @@ class RESTAPIClient(ABC):
     Abstract REST API client
     ------------------------
     REST API client handling the service url.
+
+    Arguments
+    ---------
+    service_url: str
+        Service URL for service
+    verify_calls: bool (default:= False)
+        Flag if the service calls should be verified
     """
-    def __init__(self, service_url: str = str, verify_calls: bool = False):
+    def __init__(self, service_url: str, verify_calls: bool = False):
         self.__service_url: str = service_url
         self.__verify_calls: bool = verify_calls
 
     @property
     def service_url(self) -> str:
+        """Service URL."""
         return self.__service_url
 
     @property
