@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2021 Wacom. All rights reserved.
 import enum
+import os
 import urllib.parse
 from typing import List, Dict, Any, Tuple, Optional
 
@@ -37,6 +38,12 @@ NEXT_PAGE_ID_TAG: str = 'nextPageId'
 TENANT_RIGHTS_TAG: str = 'tenantRights'
 RELATION_TAG: str = 'relation'
 
+MIME_TYPE: Dict[str, str] = {
+    '.jpg': 'image/jpeg',
+    '.jpeg': 'image/jpeg',
+    '.png': 'image/png'
+}
+
 
 # ------------------------------- Enum ---------------------------------------------------------------------------------
 class SearchPattern(enum.Enum):
@@ -79,6 +86,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
     PERSONAL_KNOWLEDGE_URL: str = 'https://semantic-ink-private.wacom.com'
     USER_ENDPOINT: str = 'user'
     ENTITY_ENDPOINT: str = 'entity'
+    ENTITY_IMAGE_ENDPOINT: str = 'entity/image/'
     ACTIVATIONS_ENDPOINT: str = 'entity/activations'
     ENTITY_URI_ENDPOINT: str = 'entity/{}'
     LABELS_ENDPOINT: str = 'entity/{}/labels'
@@ -318,7 +326,6 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         payload: dict = {
             TYPE_TAG: entity.concept_type.iri,
             DESCRIPTIONS_TAG: descriptions,
-            IMAGE_TAG: entity.image,
             LABELS_TAG: labels,
             DATA_PROPERTIES_TAG: literals
         }
@@ -327,6 +334,8 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         response: Response = requests.post(url, json=payload, headers=headers, verify=self.verify_calls)
         if response.ok:
             uri: str = response.json()[URI_TAG]
+            if entity.image is not None and entity.image != '':
+                self.set_entity_image_url(auth_key, uri, entity.image)
             return uri
 
         import json
@@ -410,7 +419,6 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         payload: dict = {
             TYPE_TAG: entity.concept_type.iri,
             DESCRIPTIONS_TAG: descriptions,
-            IMAGE_TAG: entity.image,
             LABELS_TAG: labels,
             DATA_PROPERTIES_TAG: literals
         }
@@ -989,3 +997,90 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         for elem in response['result']:
             results.append(ThingObject.from_dict(elem))
         return results, response[NEXT_PAGE_ID_TAG]
+
+    def set_entity_image_url(self, auth_key: str, entity_uri: str, image_url: str, file_name: Optional[str] = None,
+                             mime_type: Optional[str] = None) -> str:
+        """Setting the image of the entity.
+        The image for the URL is downloaded and then pushed to the backend.
+
+        Parameters
+        ----------
+        auth_key: str
+            Auth key from user
+        entity_uri: str
+            URI of the entity.
+        image_url: str
+            URL of the image.
+        file_name: str (default:=None)
+            Name of  the file. If None the name is extracted from URL.
+        mime_type: str (default:=None)
+            Mime type.
+
+        Returns
+        -------
+        image_id: str
+            ID of uploaded image
+
+        Raises
+        ------
+        WacomServiceException
+            If the graph service returns an error code.
+        """
+        response: Response = requests.get(image_url)
+        if response.ok:
+            image_bytes: bytes = response.content
+            file_name: str = image_url if file_name is None else file_name
+            if mime_type is None:
+                _, file_extension = os.path.splitext(file_name.lower())
+                if file_extension not in MIME_TYPE:
+                    raise WacomServiceException(f'Creation of entity image failed. Mime-type cannot be '
+                                                f'identified or is not supported.'
+                                                f'Response code:={response.status_code}, '
+                                                f'exception:= {response.content}')
+                mime_type = MIME_TYPE[file_extension]
+
+            return self.set_entity_image(auth_key, entity_uri, image_bytes, file_name, mime_type)
+        if not response.ok:
+            raise WacomServiceException(f'Creation of entity image failed'
+                                        f'Response code:={response.status_code}, exception:= {response.content}')
+
+    def set_entity_image(self, auth_key: str, entity_uri: str, image_byte: bytes, file_name: str = 'icon.jpg',
+                         mime_type: str = 'image/jpeg') -> str:
+        """Setting the image of the entity.
+       The image for the URL is downloaded and then pushed to the backend.
+
+       Parameters
+       ----------
+       auth_key: str
+           Auth key from user
+       entity_uri: str
+           URI of the entity.
+       image_byte: bytes
+           Binary encoded image.
+       file_name: str (default:=None)
+           Name of  the file. If None the name is extracted from URL.
+       mime_type: str (default:=None)
+           Mime type.
+
+       Returns
+       -------
+       image_id: str
+           ID of uploaded image
+
+       Raises
+       ------
+       WacomServiceException
+           If the graph service returns an error code.
+       """
+        headers: dict = {
+            AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
+        }
+        files: List[Tuple[str, Tuple[str, bytes, str]]] = [
+            ('file', (file_name, image_byte, mime_type))
+        ]
+        url: str = f'{self.service_base_url}{self.ENTITY_IMAGE_ENDPOINT}{urllib.parse.quote(entity_uri)}'
+        response = requests.patch(url, headers=headers, files=files, verify=self.verify_calls)
+        if response.ok:
+            return response.json()['imageId']
+        raise WacomServiceException(f'Creation of entity image failed'
+                                    f'Response code:={response.status_code}, exception:= {response.content}')
