@@ -2,13 +2,13 @@
 # Copyright © 2021 Wacom. All rights reserved.
 import urllib.parse
 from http import HTTPStatus
-from typing import Dict, List, Any, Optional
+from typing import Dict, List, Any, Optional, Tuple
 
 import requests
 from requests import Response
 
 from knowledge.base.entity import OntologyContext, LocalizedContent, Label, Comment
-from knowledge.base.ontology import OntologyClassReference, OntologyPropertyReference, OntologyProperty, OntologyClass, \
+from knowledge.base.ontology import OntologyClassReference, OntologyPropertyReference, OntologyProperty, OntologyClass,\
     PropertyType, THING_CLASS, DataPropertyType
 from knowledge.services.base import WacomServiceAPIClient, WacomServiceException
 from knowledge.services.graph import AUTHORIZATION_HEADER_FLAG
@@ -21,12 +21,12 @@ ICON_TAG: str = "icon"
 INVERSE_OF_TAG: str = "inverseOf"
 KIND_TAG: str = "kind"
 LABELS_TAG: str = "labels"
-LANGUAGE_CODE: str = 'locale'
+LANGUAGE_CODE: str = 'languageCode'
 NAME_TAG: str = "name"
 RANGE_TAG: str = "range"
 SUB_CLASS_OF_TAG: str = "subClassOf"
 SUB_PROPERTY_OF_TAG: str = "subPropertyOf"
-TEXT_TAG: str = 'text'
+TEXT_TAG: str = 'value'
 
 
 class OntologyService(WacomServiceAPIClient):
@@ -86,7 +86,7 @@ class OntologyService(WacomServiceAPIClient):
         raise WacomServiceException(f'Listing of context failed. '
                                     f'Response code:={response.status_code}, exception:= {response.text}')
 
-    def concepts(self, auth_key: str, context: str) -> List[OntologyClassReference]:
+    def concepts(self, auth_key: str, context: str) -> List[Tuple[OntologyClassReference, OntologyClassReference]]:
         """Retrieve all concept classes.
 
         **Remark:**
@@ -101,8 +101,8 @@ class OntologyService(WacomServiceAPIClient):
 
         Returns
         -------
-        concepts: List[OntologyClassReference]
-            List of ontology classes
+        concepts: List[Tuple[OntologyClassReference, OntologyClassReference]]
+            List of ontology classes. Tuple<Classname, Superclass>
         """
         headers: Dict[str, str] = {
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
@@ -110,14 +110,17 @@ class OntologyService(WacomServiceAPIClient):
         response: Response = requests.get(f'{self.service_base_url}{OntologyService.CONCEPTS_ENDPOINT.format(context)}',
                                           headers=headers, verify=self.verify_calls)
         if response.ok:
-            response_list: List[OntologyClassReference] = []
+            response_list: List[Tuple[OntologyClassReference, OntologyClassReference]] = []
             result = response.json()
-            for c in result:
-                response_list.append(OntologyClassReference.parse(c))
+            for struct in result:
+                response_list.append((OntologyClassReference.parse(struct[NAME_TAG]),
+                                      None if struct[SUB_CLASS_OF_TAG] is None else
+                                      OntologyClassReference.parse(struct[SUB_CLASS_OF_TAG])))
             return response_list
         raise WacomServiceException(f'Response code:={response.status_code}, exception:= {response.text}')
 
-    def properties(self, auth_key: str, context_name: str) -> List[OntologyPropertyReference]:
+    def properties(self, auth_key: str, context_name: str) -> List[Tuple[OntologyPropertyReference,
+                                                                         OntologyPropertyReference]]:
         """List all properties.
 
         **Remark:**
@@ -132,7 +135,7 @@ class OntologyService(WacomServiceAPIClient):
 
         Returns
         -------
-        contexts: List[OntologyPropertyReference]
+        contexts: List[Tuple[OntologyPropertyReference, OntologyPropertyReference]]
             List of ontology contexts
         """
         headers: Dict[str, str] = {
@@ -147,9 +150,11 @@ class OntologyService(WacomServiceAPIClient):
         if response.status_code == HTTPStatus.NOT_FOUND:
             return []
         if response.ok:
-            response_list: List[OntologyPropertyReference] = []
+            response_list: List[Tuple[OntologyPropertyReference, OntologyPropertyReference]] = []
             for c in response.json():
-                response_list.append(OntologyPropertyReference.parse(c))
+                response_list.append((OntologyPropertyReference.parse(c[NAME_TAG]),
+                                      None if c[SUB_PROPERTY_OF_TAG] is None else
+                                      OntologyPropertyReference.parse(c[SUB_PROPERTY_OF_TAG])))
             return response_list
         raise WacomServiceException(f'Response code:={response.status_code}, exception:= {response.text}')
 
